==> apache-camel-3.4.5-src.zip: apache-camel-3.4.5/core/camel-core/src/test/java/org/apache/camel/component/seda/SedaSimpleSizeTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.seda;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

public class SedaSimpleSizeTest extends ContextTestSupport {

    @Test
    public void testSedaSize() throws Exception {
        getMockEndpoint("mock:result").expectedBodiesReceived("0", "1", "2");

        template.sendBody("direct:start", "");
        template.sendBody("seda:foo", "A");

        template.sendBody("direct:start", "");
        template.sendBody("seda:foo", "B");

        template.sendBody("direct:start", "");
        template.sendBody("seda:foo", "C");

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                endpoint("seda:foo");

                from("direct:start").setBody().simple("${camelContext.getEndpoint('seda:foo').currentQueueSize}").to("mock:result");
            }
        };
    }
}

==> apache-camel-4.13.0-src.zip: apache-camel-4.13.0/core/camel-core/src/test/java/org/apache/camel/component/seda/SedaSimpleSizeTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.seda;

import org.apache.camel.ContextTestSupport;
import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

public class SedaSimpleSizeTest extends ContextTestSupport {

    @Test
    public void testSedaSize() throws Exception {
        getMockEndpoint("mock:result").expectedBodiesReceived("0", "1", "2");

        template.sendBody("direct:start", "");
        template.sendBody("seda:foo", "A");

        template.sendBody("direct:start", "");
        template.sendBody("seda:foo", "B");

        template.sendBody("direct:start", "");
        template.sendBody("seda:foo", "C");

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            @Override
            public void configure() {
                endpoint("seda:foo");

                from("direct:start").setBody().simple("${camelContext.getEndpoint('seda:foo').currentQueueSize}")
                        .to("mock:result");
            }
        };
    }
}
